package com.tuoheng.admin.service.user.query;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.tuoheng.admin.entity.User;
import com.tuoheng.admin.mapper.DeptMapper;
import com.tuoheng.admin.mapper.UserMapper;
import com.tuoheng.admin.request.user.QueryUserPageListRequest;
import com.tuoheng.admin.utils.CurrentUserUtil;
import com.tuoheng.common.core.utils.JsonResult;
import com.tuoheng.common.core.utils.StringUtils;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 *  查询用户分页列表业务层处理
 *
 * @author wanjing
 * @team tuoheng
 * @date 2022-12-08
 */
@Slf4j
@Service
public class QueryUserPageListService {

    @Autowired
    private UserMapper userMapper;

    @Autowired
    private DeptMapper deptMapper;

    /**
     * 获取部门树形列表
     *
     * @return
     */
    public JsonResult getPageList(QueryUserPageListRequest request) {
        log.info("进入查询用户分页列表业务");
        JsonResult result = this.check(request);
        if (0 != result.getCode()) {
            log.info("查询用户分页列表业务：校验失败：{}", result.getMsg());
            return result;
        }

        String tenantId = CurrentUserUtil.getTenantId();

        QueryWrapper<User> queryWrapper = this.buildQueryWrapper(request);

        // 查询分页数据
        IPage<User> page = new Page<>(request.getPage(), request.getLimit());
        IPage<User> pageData = userMapper.selectPage(page, queryWrapper);

//        if (CollectionUtil.isEmpty(pageData)) {
//            log.info("查询用户分页列表业务：获取用户列表为空");
//        }
        return JsonResult.success();
    }

    /**
     * 检查参数
     *
     * @param request
     * @return
     */
    private JsonResult check(QueryUserPageListRequest request) {

        return JsonResult.success();
    }

    private QueryWrapper<User> buildQueryWrapper(QueryUserPageListRequest request) {
        // 查询条件
        QueryWrapper<User> queryWrapper = new QueryWrapper<>();
        // 只显示非管理员用户
        //queryWrapper.ne("is_admin", 1);
        // 租户ID
        queryWrapper.eq("tenant_id", CurrentUserUtil.getTenantId());
        // 真实姓名
        if (!StringUtils.isEmpty(request.getRealname())) {
            queryWrapper.like("realname", request.getRealname());
        }
        // 用户账号
        if (!StringUtils.isEmpty(request.getUsername())) {
            queryWrapper.eq("username", request.getUsername());
        }

        //根据角色id查询
        if (StringUtils.isNotNull((request.getRoleId()))) {
            queryWrapper.eq("role_id", request.getRoleId());
        }

        // 状态筛选
        if (StringUtils.isNotNull(request.getStatus())) {
            queryWrapper.eq("status", request.getStatus());
        }
        queryWrapper.eq("mark", 1);
        queryWrapper.orderByDesc("create_time");

        return queryWrapper;
    }
}
