package com.tuoheng.admin.service.user.update;

import cn.hutool.core.util.ObjectUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.tuoheng.admin.entity.User;
import com.tuoheng.admin.enums.code.user.AddUserCodeEnum;
import com.tuoheng.admin.enums.code.user.EditUserCodeEnum;
import com.tuoheng.admin.mapper.UserMapper;
import com.tuoheng.admin.service.third.oidc.OidcService;
import com.tuoheng.admin.utils.CurrentUserUtil;
import com.tuoheng.common.core.config.common.CommonConfig;
import com.tuoheng.common.core.utils.CommonUtils;
import com.tuoheng.common.core.utils.DateUtils;
import com.tuoheng.common.core.utils.JsonResult;
import com.tuoheng.common.core.utils.StringUtils;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * 修改用户业务层处理
 *
 * @author wanjing
 * @team tuoheng
 * @date 2022-12-16
 */
@Slf4j
@Service
public class UpdateUserService {

    @Autowired
    private UserMapper userMapper;

    @Autowired
    private OidcService oidcService;

    /**
     * 修改用户数据
     *
     * @return
     */
    public JsonResult update(User user) {
        log.info("进入修改用户业务接口");
        String tenantId = CurrentUserUtil.getTenantId();
        JsonResult result = this.check(tenantId, user);
        if (0 != result.getCode()) {
            log.info("修改用户业务接口：校验失败：{}", result.getMsg());
            return result;
        }

        // 修改oidc
        result = oidcService.editUser(user);
        if (0 != result.getCode()) {
            log.info("修改用户业务接口：修改oidc数据失败：{}", result.getMsg());
            return result;
        }

        this.buildUser(user);

        Integer rowCount = userMapper.updateById(user);
        if (rowCount <= 0) {
            return JsonResult.error();
        }
        return JsonResult.success();
    }
    /**
     * 检查参数
     * @param tenantId
     * @param user
     * @return
     */
    private JsonResult check(String tenantId, User user) {
        if (StringUtils.isNotEmpty(user.getMobile())) {
            //校验手机号
            boolean flag = CommonUtils.isMobile(user.getMobile());
            if (!flag) {
                return JsonResult.error(EditUserCodeEnum.PHONE_NOT_IMATCH.getCode(), EditUserCodeEnum.PHONE_NOT_IMATCH.getMsg());
            }
        }

        User userTmp = userMapper.selectOne(new LambdaQueryWrapper<User>()
                        .eq(User::getTenantId, tenantId)
                        .eq(User::getId, user.getId())
                        .eq(User::getMark, 1));

        if (ObjectUtil.isNull(userTmp)) {
            return JsonResult.error("该用户不存在");
        }

        Integer count = userMapper.selectCount(new LambdaQueryWrapper<User>()
                .eq(User::getTenantId, tenantId)
                .eq(User::getUsername, user.getUsername())
                .eq(User::getMark, 1));
        if (count > 0) {
            return JsonResult.error(EditUserCodeEnum.USERNAME_ALREADY_EXISTS.getCode(), EditUserCodeEnum.USERNAME_ALREADY_EXISTS.getMsg());
        }

        return JsonResult.success();
    }
    /**
     *
     * 构建实体字段数据
     *
     * @param user
     */
    private void buildUser(User user) {
        if (StringUtils.isNotNull(user.getAvatar()) && user.getAvatar().contains(CommonConfig.imageURL)) {
            user.setAvatar(user.getAvatar().replaceAll(CommonConfig.imageURL, ""));
        } else {
            //添加默认头像
            user.setAvatar("imagedir/n1o1j9ndau_1670488066287.png");
        }
        user.setCityName("");
        user.setUpdateUser(CurrentUserUtil.getUserId());
        user.setUpdateTime(DateUtils.now());
    }


}
